summaryrefslogtreecommitdiffstats
path: root/part/qdom_add.h
diff options
context:
space:
mode:
Diffstat (limited to 'part/qdom_add.h')
-rw-r--r--part/qdom_add.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/part/qdom_add.h b/part/qdom_add.h
index 4e9634c..6f47426 100644
--- a/part/qdom_add.h
+++ b/part/qdom_add.h
@@ -15,41 +15,41 @@
* *
***************************************************************************/
-#ifndef QDOM_ADD_H
-#define QDOM_ADD_H
+#ifndef TQDOM_ADD_H
+#define TQDOM_ADD_H
-/** This file contains useful datatypes and functions in addition to the Qt DOM classes. */
+/** This file contains useful datatypes and functions in addition to the TQt DOM classes. */
-#include <qpixmap.h>
-#include <qdom.h>
+#include <tqpixmap.h>
+#include <tqdom.h>
class KXESearchDialog;
-extern QPixmap g_iconElement;
-extern QPixmap g_iconText;
-extern QPixmap g_iconComment;
-extern QPixmap g_iconCDATASection;
-extern QPixmap g_iconProcessingInstruction;
-extern QPixmap g_iconElement_b;
-extern QPixmap g_iconText_b;
-extern QPixmap g_iconComment_b;
-extern QPixmap g_iconCDATASection_b;
-extern QPixmap g_iconProcessingInstruction_b;
+extern TQPixmap g_iconElement;
+extern TQPixmap g_iconText;
+extern TQPixmap g_iconComment;
+extern TQPixmap g_iconCDATASection;
+extern TQPixmap g_iconProcessingInstruction;
+extern TQPixmap g_iconElement_b;
+extern TQPixmap g_iconText_b;
+extern TQPixmap g_iconComment_b;
+extern TQPixmap g_iconCDATASection_b;
+extern TQPixmap g_iconProcessingInstruction_b;
/** Returns the corresponding pixmap/icon to the given node type. */
-const QPixmap & domTool_getIconForNodeType( QDomNode::NodeType type, bool );
+const TQPixmap & domTool_getIconForNodeType( TQDomNode::NodeType type, bool );
/** Returns the path of the given node. */
-QString domTool_getPath( const QDomNode & );
+TQString domTool_getPath( const TQDomNode & );
/** Returns the path of the given node. */
-QString domTool_getPath( const QDomElement & );
+TQString domTool_getPath( const TQDomElement & );
/** Returns the level (how deep in tree) of the given node. */
-unsigned int domTool_getLevel( const QDomNode & );
+unsigned int domTool_getLevel( const TQDomNode & );
-/** Returns a QString with the XML representation of the given node including all its children (uses @ref QDomNode::save). */
-QString domTool_save( const QDomNode &, int );
+/** Returns a TQString with the XML representation of the given node including all its children (uses @ref TQDomNode::save). */
+TQString domTool_save( const TQDomNode &, int );
/**
* Returns the previous node of the given one or an empty node, if it is the first.
@@ -58,23 +58,23 @@ QString domTool_save( const QDomNode &, int );
* if there is no sibling above, it will be its parent or
* an empty node (if there is no parent).
*/
-QDomNode domTool_prevNode( const QDomNode & node );
+TQDomNode domTool_prevNode( const TQDomNode & node );
/**
* Returns the next node of the given one or an empty node, if it is the last.
* This will be it's first child,
* if there are no childs, it will be the next sibling
* and if there are no siblings below, it will be the parent's next sibling ...
*/
-QDomNode domTool_nextNode( const QDomNode & node );
+TQDomNode domTool_nextNode( const TQDomNode & node );
/**
* Tests the given node and its (grand)childs.
* Returns the node, which matches the given path, oran empty node (if no one matches).
*/
-QDomNode domTool_matchingNode( const QDomNode & node, const QString & szPath );
+TQDomNode domTool_matchingNode( const TQDomNode & node, const TQString & szPath );
/** Tests, if the given node matches the conditions of the given search. */
-bool domTool_match( QDomNode node, const KXESearchDialog * const pConditions );
+bool domTool_match( TQDomNode node, const KXESearchDialog * const pConditions );
#endif